xquery version "3.1";

(: This library module contains XQSuite tests for the presorting module stored 
 : in ../presort.xqm :)

module namespace presort-test = "http://fontane-nb.dariah.eu/presort-test";

import module namespace presort="http://fontane-nb.dariah.eu/presort" at "../presort.xqm";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace test="http://exist-db.org/xquery/xqsuite";


(: Text :)
declare
    %test:name("Text nodes")
    %test:args("Just some text")
    %test:assertEquals("Just some text")    
    
    %test:args("Text with Ümläöuts")
    %test:assertEquals("Text with Ümläöuts")    
    
    %test:args("Hiſtoriſches ✓")
    %test:assertEquals("Hiſtoriſches ✓")
    function presort-test:text($node as text()) {
        presort:sort($node)
};

(: Default nodes :)
declare
    %test:name("Default nodes")
    %test:args("<handShift xmlns:tei=""http://www.tei-c.org/ns/1.0"" medium=""pencil"" script=""Latf""/>")
    %test:assertEquals("<handShift xmlns:tei=""http://www.tei-c.org/ns/1.0"" medium=""pencil"" script=""Latf""/>")
    
    %test:args("<seg xmlns:tei=""http://www.tei-c.org/ns/1.0""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg>")
    %test:assertEquals("<seg xmlns:tei=""http://www.tei-c.org/ns/1.0""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg>")    
    function presort-test:default-nodes($node as element(*)) {
        presort:sort($node)
};


(: @next nodes :)
declare
    %test:name("Establishing right order with @next nodes")
    (: case 1: two elements referencing each other also stand right next to each
    other, i.e. there's no text inbetween. then nothing should happen :)
    %test:args("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><zone xmlns:tei=""http://www.tei-c.org/ns/1.0"" type=""item""><line>in das <rs next=""#C07_1r_b"" ref=""plc:Kloster_EF"" xml:id=""C07_1r_a"" type=""direct"">Auguſtinerkloſter</rs></line><line><rs ref=""plc:Kloster_EF"" prev=""#C07_1r_a"" xml:id=""C07_1r_b"" type=""direct"">zu Erfurt</rs></line></zone></text>")
    %test:assertEquals("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><zone xmlns:tei=""http://www.tei-c.org/ns/1.0"" type=""item""><line>in das <rs next=""#C07_1r_b"" ref=""plc:Kloster_EF"" xml:id=""C07_1r_a"" type=""direct"">Auguſtinerkloſter</rs></line><line><rs ref=""plc:Kloster_EF"" prev=""#C07_1r_a"" xml:id=""C07_1r_b"" type=""direct"">zu Erfurt</rs></line></zone></text>")
    
    (: case 2: two elements referencing each other are seperated by an arbitrary
    amout of text. then they should be sorted into the right order :)
    %test:args("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><zone><line next=""#C07_1r_13"" xml:id=""C07_1r_q"">2. Luther, <hi>Eisleben</hi><date when-iso=""1483"" type=""asynchronous"">1483</date></line><line>Some Text</line></zone><zone prev=""#C07_1r_q"" type=""item"" xml:id=""C07_1r_13""><handShift medium=""brown_ink thin_pen""/><line>Ein Stück ſeines Mantels und ſei</line></zone></text>")
    %test:assertEquals("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><zone><line next=""#C07_1r_13"" xml:id=""C07_1r_q"">2. Luther, <hi>Eisleben</hi><date when-iso=""1483"" type=""asynchronous"">1483</date></line><zone prev=""#C07_1r_q"" type=""item"" xml:id=""C07_1r_13""><handShift medium=""brown_ink thin_pen""/><line>Ein Stück ſeines Mantels und ſei</line></zone><line>Some Text</line></zone></text>")
    
    function presort-test:next-nodes($node as element(*)) {
        presort:sort($node)
};


(: @prev nodes :)
declare
    %test:name("Omit @prev nodes")
    %test:args("<handShift xmlns:tei=""http://www.tei-c.org/ns/1.0"" medium=""pencil"" script=""Latf""/>")
    %test:assertEquals("<handShift xmlns:tei=""http://www.tei-c.org/ns/1.0"" medium=""pencil"" script=""Latf""/>")    
    
    %test:args("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><seg xml:id=""some_id"" next=""#id""/><seg xml:id=""id"" prev=""#some_id""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg></text>")  
    %test:assertEquals("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><seg xml:id=""some_id"" next=""#id""/><seg xml:id=""id"" prev=""#some_id""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg></text>")  
    
    %test:args("<seg xmlns:tei=""http://www.tei-c.org/ns/1.0"" prev=""#some_id"" next=""#some_other_id""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg>")
    %test:assertEquals("<seg xmlns:tei=""http://www.tei-c.org/ns/1.0"" prev=""#some_id"" next=""#some_other_id""><stamp xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg>")    
    
    %test:args("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><seg xml:id=""some_id"" next=""#id""/><seg xmlns:tei=""http://www.tei-c.org/ns/1.0"" xml:id=""id"" prev=""#some_id"" next=""#some_other_id""><stamp prev=""#id"" xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg><seg xml:id=""some_other_id""/></text>")
    %test:assertEquals("<text xmlns:tei=""http://www.tei-c.org/ns/1.0""><seg xml:id=""some_id"" next=""#id""/><seg xmlns:tei=""http://www.tei-c.org/ns/1.0"" xml:id=""id"" prev=""#some_id"" next=""#some_other_id""><stamp prev=""#id"" xmlns:tei=""http://www.tei-c.org/ns/1.0"">STAATSBIBLIOTHEK •BERLIN•</stamp></seg><seg xml:id=""some_other_id""/></text>")
    function presort-test:omit-prev-nodes($node as element(*)) {
        presort:sort($node)
};
